@@ -36,6 +36,11 @@ class BaseCart(
 
     _tax_ratio = 1.05
 
+    # 結帳時訂單折扣後價格使用點數的比例
+    _use_points_ratio = 1
+    # 點數對金額的比例
+    _points_ratio: int = 1
+
     INITIAL_CART = {
         "items": [],
         "extra_items": [],
@@ -65,7 +70,10 @@ class BaseCart(
 
     @property
     def sales(self) -> int:
-        return round(self.total / self._tax_ratio)
+        sales_amount = sum(item.sales_amount for item in self.items)
+        sales_fee = round(self._fee / self._tax_ratio, 7)
+        sales_discount = round(self._discount / self._tax_ratio, 7)
+        return round(sales_amount + sales_fee - sales_discount)
 
     @property
     def tax(self) -> int:
@@ -73,7 +81,8 @@ class BaseCart(
 
     def __getattr__(self, item: str) -> Any:
         if item in self.config_cls.__fields__:
-            return self._cache_cart[item]
+            _model_field = self.config_cls.__fields__[item]
+            return self._cache_cart.get(item, _model_field.default)
         return self.__dict__[item]
 
     def __setattr__(self, key: str, value: Any) -> None:
@@ -193,10 +202,10 @@ class BaseCart(
         self._cache_cart["discount_items"] = discount_items
 
     def _load_cart(self, identity: str) -> MutableMapping[str, Any]:
-        cart = get_collection("cart").find_one({"owner": identity})
+        cart = get_collection("cart").find_one({"owner": str(identity)})
         if not cart:
             cart = {
-                "owner": identity,
+                "owner": str(identity),
                 **self.INITIAL_CART,
                 **self.config_cls.validate_optional(self._init_cart_extra()).dict(),
             }
