@@ -32,6 +32,7 @@ class PaymentSubTypes(str, Enum):
     atm = "atm"
     credit = "credit"
     cod = "cod"
+    offline = "offline"
 
 
 class LogisticTypes(str, Enum):
@@ -92,6 +93,8 @@ class CartConfig(BaseCartConfig):
     # B2C 載具編號 如果 carrier_type = "1" 載具編號放空字串即可， ecpay 會拿 customer email or phone
     invoice_carrier_num: str = ""
     order_note: str = ""
+    points: int = 0
+    use_full_points: bool = False
     extra_data: Optional[Any]
 
     @validator("logistics_subtype")
